badwing.physics package
=======================

Submodules
----------

badwing.physics.dynamic module
------------------------------

.. automodule:: badwing.physics.dynamic
   :members:
   :undoc-members:
   :show-inheritance:

badwing.physics.engine module
-----------------------------

.. automodule:: badwing.physics.engine
   :members:
   :undoc-members:
   :show-inheritance:

badwing.physics.kinematic module
--------------------------------

.. automodule:: badwing.physics.kinematic
   :members:
   :undoc-members:
   :show-inheritance:

badwing.physics.physics module
------------------------------

.. automodule:: badwing.physics.physics
   :members:
   :undoc-members:
   :show-inheritance:

badwing.physics.static module
-----------------------------

.. automodule:: badwing.physics.static
   :members:
   :undoc-members:
   :show-inheritance:

badwing.physics.util module
---------------------------

.. automodule:: badwing.physics.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.physics
   :members:
   :undoc-members:
   :show-inheritance:
